==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/AzureTableSinkResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * A copy activity Azure Table sink.
 * @property azureTableDefaultPartitionKeyValue Azure Table default partition key value. Type: string (or Expression with resultType string).
 * @property azureTableInsertType Azure Table insert type. Type: string (or Expression with resultType string).
 * @property azureTablePartitionKeyName Azure Table partition key name. Type: string (or Expression with resultType string).
 * @property azureTableRowKeyName Azure Table row key name. Type: string (or Expression with resultType string).
 * @property disableMetricsCollection If true, disable data store metrics collection. Default is false. Type: boolean (or Expression with resultType boolean).
 * @property maxConcurrentConnections The maximum concurrent connection count for the sink data store. Type: integer (or Expression with resultType integer).
 * @property sinkRetryCount Sink retry count. Type: integer (or Expression with resultType integer).
 * @property sinkRetryWait Sink retry wait. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 * @property type Copy sink type.
 * Expected value is 'AzureTableSink'.
 * @property writeBatchSize Write batch size. Type: integer (or Expression with resultType integer), minimum: 0.
 * @property writeBatchTimeout Write batch timeout. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 */
public data class AzureTableSinkResponse(
    public val azureTableDefaultPartitionKeyValue: Any? = null,
    public val azureTableInsertType: Any? = null,
    public val azureTablePartitionKeyName: Any? = null,
    public val azureTableRowKeyName: Any? = null,
    public val disableMetricsCollection: Any? = null,
    public val maxConcurrentConnections: Any? = null,
    public val sinkRetryCount: Any? = null,
    public val sinkRetryWait: Any? = null,
    public val type: String,
    public val writeBatchSize: Any? = null,
    public val writeBatchTimeout: Any? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.AzureTableSinkResponse):
            AzureTableSinkResponse = AzureTableSinkResponse(
            azureTableDefaultPartitionKeyValue = javaType.azureTableDefaultPartitionKeyValue().map({ args0 ->
                args0
            }).orElse(null),
            azureTableInsertType = javaType.azureTableInsertType().map({ args0 -> args0 }).orElse(null),
            azureTablePartitionKeyName = javaType.azureTablePartitionKeyName().map({ args0 ->
                args0
            }).orElse(null),
            azureTableRowKeyName = javaType.azureTableRowKeyName().map({ args0 -> args0 }).orElse(null),
            disableMetricsCollection = javaType.disableMetricsCollection().map({ args0 -> args0 }).orElse(null),
            maxConcurrentConnections = javaType.maxConcurrentConnections().map({ args0 -> args0 }).orElse(null),
            sinkRetryCount = javaType.sinkRetryCount().map({ args0 -> args0 }).orElse(null),
            sinkRetryWait = javaType.sinkRetryWait().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            writeBatchSize = javaType.writeBatchSize().map({ args0 -> args0 }).orElse(null),
            writeBatchTimeout = javaType.writeBatchTimeout().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/outputs/AzureTableSinkResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.outputs

import kotlin.Any
import kotlin.String
import kotlin.Suppress

/**
 * A copy activity Azure Table sink.
 * @property azureTableDefaultPartitionKeyValue Azure Table default partition key value. Type: string (or Expression with resultType string).
 * @property azureTableInsertType Azure Table insert type. Type: string (or Expression with resultType string).
 * @property azureTablePartitionKeyName Azure Table partition key name. Type: string (or Expression with resultType string).
 * @property azureTableRowKeyName Azure Table row key name. Type: string (or Expression with resultType string).
 * @property disableMetricsCollection If true, disable data store metrics collection. Default is false. Type: boolean (or Expression with resultType boolean).
 * @property maxConcurrentConnections The maximum concurrent connection count for the sink data store. Type: integer (or Expression with resultType integer).
 * @property sinkRetryCount Sink retry count. Type: integer (or Expression with resultType integer).
 * @property sinkRetryWait Sink retry wait. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 * @property type Copy sink type.
 * Expected value is 'AzureTableSink'.
 * @property writeBatchSize Write batch size. Type: integer (or Expression with resultType integer), minimum: 0.
 * @property writeBatchTimeout Write batch timeout. Type: string (or Expression with resultType string), pattern: ((\d+)\.)?(\d\d):(60|([0-5][0-9])):(60|([0-5][0-9])).
 */
public data class AzureTableSinkResponse(
    public val azureTableDefaultPartitionKeyValue: Any? = null,
    public val azureTableInsertType: Any? = null,
    public val azureTablePartitionKeyName: Any? = null,
    public val azureTableRowKeyName: Any? = null,
    public val disableMetricsCollection: Any? = null,
    public val maxConcurrentConnections: Any? = null,
    public val sinkRetryCount: Any? = null,
    public val sinkRetryWait: Any? = null,
    public val type: String,
    public val writeBatchSize: Any? = null,
    public val writeBatchTimeout: Any? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datafactory.outputs.AzureTableSinkResponse): AzureTableSinkResponse = AzureTableSinkResponse(
            azureTableDefaultPartitionKeyValue = javaType.azureTableDefaultPartitionKeyValue().map({ args0 ->
                args0
            }).orElse(null),
            azureTableInsertType = javaType.azureTableInsertType().map({ args0 -> args0 }).orElse(null),
            azureTablePartitionKeyName = javaType.azureTablePartitionKeyName().map({ args0 ->
                args0
            }).orElse(null),
            azureTableRowKeyName = javaType.azureTableRowKeyName().map({ args0 -> args0 }).orElse(null),
            disableMetricsCollection = javaType.disableMetricsCollection().map({ args0 -> args0 }).orElse(null),
            maxConcurrentConnections = javaType.maxConcurrentConnections().map({ args0 -> args0 }).orElse(null),
            sinkRetryCount = javaType.sinkRetryCount().map({ args0 -> args0 }).orElse(null),
            sinkRetryWait = javaType.sinkRetryWait().map({ args0 -> args0 }).orElse(null),
            type = javaType.type(),
            writeBatchSize = javaType.writeBatchSize().map({ args0 -> args0 }).orElse(null),
            writeBatchTimeout = javaType.writeBatchTimeout().map({ args0 -> args0 }).orElse(null),
        )
    }
}
